You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2012/02/14 17:18:50 UTC

svn commit: r1244107 [4/18] - in /commons/proper/math/trunk: ./ src/main/java/org/apache/commons/math/ src/main/java/org/apache/commons/math3/ src/main/java/org/apache/commons/math3/analysis/ src/main/java/org/apache/commons/math3/analysis/function/ sr...

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/LaguerreSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/LaguerreSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/LaguerreSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/LaguerreSolver.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.complex.Complex;
-import org.apache.commons.math.exception.NoBracketingException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.complex.Complex;
+import org.apache.commons.math3.exception.NoBracketingException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implements the <a href="http://mathworld.wolfram.com/LaguerresMethod.html">
@@ -196,7 +196,7 @@ public class LaguerreSolver extends Abst
          * @param coefficients Polynomial coefficients.
          * @param initial Start value.
          * @return the point at which the function value is zero.
-         * @throws org.apache.commons.math.exception.TooManyEvaluationsException
+         * @throws org.apache.commons.math3.exception.TooManyEvaluationsException
          * if the maximum number of evaluations is exceeded.
          * @throws NullArgumentException if the {@code coefficients} is
          * {@code null}.
@@ -242,7 +242,7 @@ public class LaguerreSolver extends Abst
          * @param coefficients Polynomial coefficients.
          * @param initial Start value.
          * @return the point at which the function value is zero.
-         * @throws org.apache.commons.math.exception.TooManyEvaluationsException
+         * @throws org.apache.commons.math3.exception.TooManyEvaluationsException
          * if the maximum number of evaluations is exceeded.
          * @throws NullArgumentException if the {@code coefficients} is
          * {@code null}.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements the <a href="http://mathworld.wolfram.com/MullersMethod.html">

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver2.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver2.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver2.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/MullerSolver2.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.exception.NoBracketingException;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NoBracketingException;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements the <a href="http://mathworld.wolfram.com/MullersMethod.html">

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/NewtonSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/NewtonSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/NewtonSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/NewtonSolver.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.analysis.DifferentiableUnivariateFunction;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.DifferentiableUnivariateFunction;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implements <a href="http://mathworld.wolfram.com/NewtonsMethod.html">
@@ -55,9 +55,9 @@ public class NewtonSolver extends Abstra
      * @param max Upper bound for the interval.
      * @param maxEval Maximum number of evaluations.
      * @return the value where the function is zero.
-     * @throws org.apache.commons.math.exception.TooManyEvaluationsException
+     * @throws org.apache.commons.math3.exception.TooManyEvaluationsException
      * if the maximum evaluation count is exceeded.
-     * @throws org.apache.commons.math.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
      * if {@code min >= max}.
      */
     @Override

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PegasusSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PegasusSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PegasusSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PegasusSolver.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
 /**
  * Implements the <em>Pegasus</em> method for root-finding (approximating

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PolynomialSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PolynomialSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PolynomialSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/PolynomialSolver.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.analysis.polynomials.PolynomialFunction;
+import org.apache.commons.math3.analysis.polynomials.PolynomialFunction;
 
 /**
  * Interface for (polynomial) root-finding algorithms.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RegulaFalsiSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RegulaFalsiSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RegulaFalsiSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RegulaFalsiSolver.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
 /**
  * Implements the <em>Regula Falsi</em> or <em>False position</em> method for

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RiddersSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RiddersSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RiddersSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/RiddersSolver.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implements the <a href="http://mathworld.wolfram.com/RiddersMethod.html">

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/SecantSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/SecantSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/SecantSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/SecantSolver.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implements the <em>Secant</em> method for root-finding (approximating a

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolver.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.analysis.UnivariateFunction;
+import org.apache.commons.math3.analysis.UnivariateFunction;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolverUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolverUtils.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolverUtils.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/UnivariateSolverUtils.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;
 
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.exception.NoBracketingException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.exception.NoBracketingException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Utility routines for {@link UnivariateSolver} objects.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/solvers/package-info.java Tue Feb 14 16:17:55 2012
@@ -19,4 +19,4 @@
  *     Root finding algorithms, for univariate real functions.
  *
  */
-package org.apache.commons.math.analysis.solvers;
+package org.apache.commons.math3.analysis.solvers;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/Complex.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/Complex.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/Complex.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/Complex.java Tue Feb 14 16:17:55 2012
@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.complex;
+package org.apache.commons.math3.complex;
 
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NotPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NotPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Representation of a Complex number, i.e. a number which has both a
@@ -45,8 +45,8 @@ import org.apache.commons.math.util.Fast
  * Note that this is in contradiction with the IEEE-754 standard for floating
  * point numbers (according to which the test {@code x == x} must fail if
  * {@code x} is {@code NaN}). The method
- * {@link org.apache.commons.math.util.Precision#equals(double,double,int)
- * equals for primitive double} in {@link org.apache.commons.math.util.Precision}
+ * {@link org.apache.commons.math3.util.Precision#equals(double,double,int)
+ * equals for primitive double} in {@link org.apache.commons.math3.util.Precision}
  * conforms with IEEE-754 while this class conforms with the standard behavior
  * for Java object types.
  * <br/>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexField.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexField.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexField.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexField.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.complex;
+package org.apache.commons.math3.complex;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Representation of the complex numbers field.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexFormat.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexFormat.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexFormat.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexFormat.java Tue Feb 14 16:17:55 2012
@@ -15,20 +15,20 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.complex;
+package org.apache.commons.math3.complex;
 
 import java.text.FieldPosition;
 import java.text.NumberFormat;
 import java.text.ParsePosition;
 import java.util.Locale;
 
-import org.apache.commons.math.util.CompositeFormat;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.MathParseException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathInternalError;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NoDataException;
+import org.apache.commons.math3.util.CompositeFormat;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathParseException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathInternalError;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NoDataException;
 
 /**
  * Formats a Complex number in cartesian format "Re(c) + Im(c)i".  'i' can

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexUtils.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/RootsOfUnity.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/RootsOfUnity.java Tue Feb 14 16:17:55 2012
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.complex;
+package org.apache.commons.math3.complex;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.ZeroException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.ZeroException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * A helper class for the computation and caching of the {@code n}-th roots of

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/package-info.java Tue Feb 14 16:17:55 2012
@@ -20,4 +20,4 @@
  *     functions.
  *
  */
-package org.apache.commons.math.complex;
+package org.apache.commons.math3.complex;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/BracketingNthOrderBrentSolverDFP.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/BracketingNthOrderBrentSolverDFP.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/BracketingNthOrderBrentSolverDFP.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/BracketingNthOrderBrentSolverDFP.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.dfp;
+package org.apache.commons.math3.dfp;
 
 
-import org.apache.commons.math.analysis.solvers.AllowedSolution;
-import org.apache.commons.math.exception.MathInternalError;
-import org.apache.commons.math.exception.NoBracketingException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.util.Incrementor;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.analysis.solvers.AllowedSolution;
+import org.apache.commons.math3.exception.MathInternalError;
+import org.apache.commons.math3.exception.NoBracketingException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.util.Incrementor;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * This class implements a modification of the <a
@@ -148,9 +148,9 @@ public class BracketingNthOrderBrentSolv
      * @param allowedSolution The kind of solutions that the root-finding algorithm may
      * accept as solutions.
      * @return a value where the function is zero.
-     * @throws org.apache.commons.math.exception.MathIllegalArgumentException
+     * @throws org.apache.commons.math3.exception.MathIllegalArgumentException
      * if the arguments do not satisfy the requirements specified by the solver.
-     * @throws org.apache.commons.math.exception.TooManyEvaluationsException if
+     * @throws org.apache.commons.math3.exception.TooManyEvaluationsException if
      * the allowed number of evaluations is exceeded.
      */
     public Dfp solve(final int maxEval, final UnivariateDfpFunction f,
@@ -172,9 +172,9 @@ public class BracketingNthOrderBrentSolv
      * @param allowedSolution The kind of solutions that the root-finding algorithm may
      * accept as solutions.
      * @return a value where the function is zero.
-     * @throws org.apache.commons.math.exception.MathIllegalArgumentException
+     * @throws org.apache.commons.math3.exception.MathIllegalArgumentException
      * if the arguments do not satisfy the requirements specified by the solver.
-     * @throws org.apache.commons.math.exception.TooManyEvaluationsException if
+     * @throws org.apache.commons.math3.exception.TooManyEvaluationsException if
      * the allowed number of evaluations is exceeded.
      */
     public Dfp solve(final int maxEval, final UnivariateDfpFunction f,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/Dfp.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/Dfp.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpDec.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpDec.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.dfp;
+package org.apache.commons.math3.dfp;
 
 /** Subclass of {@link Dfp} which hides the radix-10000 artifacts of the superclass.
  * This should give outward appearances of being a decimal number with DIGITS*4-3

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpField.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpField.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpField.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpField.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.dfp;
+package org.apache.commons.math3.dfp;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
 
 /** Field for Decimal floating point instances.
  * @version $Id$

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpMath.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpMath.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpMath.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpMath.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.dfp;
+package org.apache.commons.math3.dfp;
 
 /** Mathematical routines for use with {@link Dfp}.
  * The constants are defined in {@link DfpField}

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/UnivariateDfpFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/UnivariateDfpFunction.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/UnivariateDfpFunction.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/UnivariateDfpFunction.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.dfp;
+package org.apache.commons.math3.dfp;
 
 /**
  * An interface representing a univariate {@link Dfp} function.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/package-info.java Tue Feb 14 16:17:55 2012
@@ -85,4 +85,4 @@
  * this can be rendered invisible by a subclass.</p>
  *
  */
-package org.apache.commons.math.dfp;
+package org.apache.commons.math3.dfp;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractIntegerDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractIntegerDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractIntegerDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractIntegerDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.MathInternalError;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.random.RandomDataImpl;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathInternalError;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.random.RandomDataImpl;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Base class for integer-valued discrete distributions.  Default

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractRealDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractRealDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractRealDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/AbstractRealDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.analysis.solvers.UnivariateSolverUtils;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.random.RandomDataImpl;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.analysis.solvers.UnivariateSolverUtils;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.random.RandomDataImpl;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Base class for probability distributions on the reals.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BetaDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BetaDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BetaDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BetaDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Gamma;
-import org.apache.commons.math.special.Beta;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Gamma;
+import org.apache.commons.math3.special.Beta;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implements the Beta distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BinomialDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BinomialDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BinomialDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/BinomialDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.NotPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Beta;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.NotPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Beta;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the binomial distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/CauchyDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/CauchyDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/CauchyDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/CauchyDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the Cauchy distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ChiSquaredDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ChiSquaredDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ChiSquaredDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ChiSquaredDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
 /**
  * Implementation of the chi-squared distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ExponentialDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ExponentialDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ExponentialDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ExponentialDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the exponential distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/FDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/FDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/FDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/FDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Beta;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Beta;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the F-distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/GammaDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/GammaDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/GammaDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/GammaDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Gamma;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Gamma;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the Gamma distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/HypergeometricDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/HypergeometricDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/HypergeometricDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/HypergeometricDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotPositiveException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.ArithmeticUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotPositiveException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.ArithmeticUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the hypergeometric distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/IntegerDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/IntegerDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/IntegerDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/IntegerDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.OutOfRangeException;
 
 /**
  * Interface for distributions on the integers.
@@ -148,7 +148,7 @@ public interface IntegerDistribution {
      *
      * @param sampleSize the number of random values to generate
      * @return an array representing the random sample
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if {@code sampleSize} is not positive
      * @since 3.0
      */

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/KolmogorovSmirnovDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/KolmogorovSmirnovDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/LogNormalDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/LogNormalDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Erf;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Erf;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the log-normal (gaussian) distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/NormalDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/NormalDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/NormalDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/NormalDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Erf;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Erf;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the normal (gaussian) distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PascalDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PascalDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PascalDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PascalDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Beta;
-import org.apache.commons.math.util.ArithmeticUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Beta;
+import org.apache.commons.math3.util.ArithmeticUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * <p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PoissonDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PoissonDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PoissonDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/PoissonDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Gamma;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Gamma;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the Poisson distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/RealDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/RealDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/RealDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/RealDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.OutOfRangeException;
 
 /**
  * Base interface for distributions on the reals.
@@ -176,7 +176,7 @@ public interface RealDistribution {
      *
      * @param sampleSize the number of random values to generate
      * @return an array representing the random sample
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if {@code sampleSize} is not positive
      */
     double[] sample(int sampleSize);

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/SaddlePointExpansion.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/SaddlePointExpansion.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/SaddlePointExpansion.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/SaddlePointExpansion.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.special.Gamma;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.special.Gamma;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * <p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TDistribution.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Beta;
-import org.apache.commons.math.special.Gamma;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Beta;
+import org.apache.commons.math3.special.Gamma;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of Student's t-distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TriangularDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TriangularDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TriangularDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/TriangularDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the triangular real distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformIntegerDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformIntegerDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformIntegerDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformIntegerDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Implementation of the uniform integer distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformRealDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformRealDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformRealDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/UniformRealDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Implementation of the uniform real distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/WeibullDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/WeibullDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/WeibullDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/WeibullDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.special.Gamma;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.special.Gamma;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the Weibull distribution. This implementation uses the

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ZipfDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ZipfDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ZipfDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/ZipfDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Implementation of the Zipf distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Implementations of common discrete and continuous distributions.
  */
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/ConvergenceException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/ConvergenceException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/ConvergenceException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/ConvergenceException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Error thrown when a numerical computation can not be performed because the

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/DimensionMismatchException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/DimensionMismatchException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/DimensionMismatchException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/DimensionMismatchException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.Localizable;
 
 /**
  * Exception to be thrown when two dimensions differ.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathArithmeticException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathArithmeticException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathArithmeticException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathArithmeticException.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.util.ExceptionContext;
-import org.apache.commons.math.exception.util.ExceptionContextProvider;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.ExceptionContext;
+import org.apache.commons.math3.exception.util.ExceptionContextProvider;
 
 /**
  * Base class for arithmetic exceptions.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalArgumentException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalArgumentException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalArgumentException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalArgumentException.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.ExceptionContext;
-import org.apache.commons.math.exception.util.ExceptionContextProvider;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.ExceptionContext;
+import org.apache.commons.math3.exception.util.ExceptionContextProvider;
 
 /**
  * Base class for all preconditions violation exceptions.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalNumberException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalNumberException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalNumberException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalNumberException.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.Localizable;
 
 /**
  * Base class for exceptions raised by a wrong number.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalStateException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalStateException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalStateException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathIllegalStateException.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.util.ExceptionContext;
-import org.apache.commons.math.exception.util.ExceptionContextProvider;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.ExceptionContext;
+import org.apache.commons.math3.exception.util.ExceptionContextProvider;
 
 /**
  * Base class for all exceptions that signal a mismatch between the

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathInternalError.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathInternalError.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathInternalError.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathInternalError.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception triggered when something that shouldn't happen does happen.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathParseException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathParseException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathParseException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathParseException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.ExceptionContextProvider;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.ExceptionContextProvider;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Class to signal parse failures.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathUnsupportedOperationException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathUnsupportedOperationException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathUnsupportedOperationException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MathUnsupportedOperationException.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.util.ExceptionContext;
-import org.apache.commons.math.exception.util.ExceptionContextProvider;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.ExceptionContext;
+import org.apache.commons.math3.exception.util.ExceptionContextProvider;
 
 /**
  * Base class for all unsupported features.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MaxCountExceededException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MaxCountExceededException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MaxCountExceededException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MaxCountExceededException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when some counter maximum value is exceeded.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MultiDimensionMismatchException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MultiDimensionMismatchException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MultiDimensionMismatchException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/MultiDimensionMismatchException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when two sets of dimensions differ.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoBracketingException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoBracketingException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoBracketingException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoBracketingException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when function values have the same sign at both

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoDataException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoDataException.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoDataException.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/exception/NoDataException.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.exception;
+package org.apache.commons.math3.exception;
 
-import org.apache.commons.math.exception.util.Localizable;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when the required data is missing.
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexUtils.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/ComplexUtils.java Tue Feb 14 16:17:55 2012
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.complex;
+package org.apache.commons.math3.complex;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Static implementations of common
  * {@link org.apache.commons.math.complex.Complex} utilities functions.
  *
  * @version $Id$
  */
@@ -15,15 +15,15 @@
 /**
  * Static implementations of common
- * {@link org.apache.commons.math.complex.Complex} utilities functions.
+ * {@link org.apache.commons.math3.complex.Complex} utilities functions.
  *
  * @version $Id$

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/RootsOfUnity.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/complex/RootsOfUnity.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/Dfp.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/Dfp.java Tue Feb 14 16:17:55 2012
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.dfp;
+package org.apache.commons.math3.dfp;
 
 import java.util.Arrays;
 
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.FieldElement;
 
 /**
  *  Decimal floating point library for Java
@@ -624,12 +624,12 @@ public class Dfp implements FieldElement
         return field.newDfp(sig, code);
     }
 
     /** Get the {@link org.apache.commons.math.Field Field} (really a {@link DfpField}) to which the instance belongs.
      * <p>
      * The field is linked to the number of digits and acts as a factory
      * for {@link Dfp} instances.
      * </p>
      * @return {@link org.apache.commons.math.Field Field} (really a {@link DfpField}) to which the instance belongs
      */
     public DfpField getField() {
         return field;
@@ -624,12 +624,12 @@ public class Dfp implements FieldElement
     }
 
-    /** Get the {@link org.apache.commons.math.Field Field} (really a {@link DfpField}) to which the instance belongs.
+    /** Get the {@link org.apache.commons.math3.Field Field} (really a {@link DfpField}) to which the instance belongs.
      * <p>
      * The field is linked to the number of digits and acts as a factory
@@ -624,12 +624,12 @@ public class Dfp implements FieldElement
      * for {@link Dfp} instances.
      * </p>
-     * @return {@link org.apache.commons.math.Field Field} (really a {@link DfpField}) to which the instance belongs
+     * @return {@link org.apache.commons.math3.Field Field} (really a {@link DfpField}) to which the instance belongs
      */
     public DfpField getField() {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpDec.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/dfp/DfpDec.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/KolmogorovSmirnovDistribution.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/KolmogorovSmirnovDistribution.java Tue Feb 14 16:17:55 2012
@@ -15,22 +15,22 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.distribution;
+package org.apache.commons.math3.distribution;
 
 import java.io.Serializable;
 import java.math.BigDecimal;
 
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.fraction.BigFraction;
-import org.apache.commons.math.fraction.BigFractionField;
-import org.apache.commons.math.fraction.FractionConversionException;
-import org.apache.commons.math.linear.Array2DRowFieldMatrix;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.linear.FieldMatrix;
-import org.apache.commons.math.linear.RealMatrix;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.fraction.BigFraction;
+import org.apache.commons.math3.fraction.BigFractionField;
+import org.apache.commons.math3.fraction.FractionConversionException;
+import org.apache.commons.math3.linear.Array2DRowFieldMatrix;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.linear.FieldMatrix;
+import org.apache.commons.math3.linear.RealMatrix;
 
 /**
  * Implementation of the Kolmogorov-Smirnov distribution.
@@ -96,12 +96,12 @@ public class KolmogorovSmirnovDistributi
      * exact as with
      * {@link KolmogorovSmirnovDistribution#cdfExact(double)} because
      * calculations are based on {@code double} rather than
-     * {@link org.apache.commons.math.fraction.BigFraction}.
+     * {@link org.apache.commons.math3.fraction.BigFraction}.
      *
      * @param d statistic
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
      * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
      */
@@ -121,7 +121,7 @@ public class KolmogorovSmirnovDistributi
      * @param d statistic
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
      * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
      */
@@ -135,14 +135,14 @@ public class KolmogorovSmirnovDistributi
      *
      * @param d statistic
      * @param exact whether the probability should be calculated exact using
      * {@link org.apache.commons.math.fraction.BigFraction} everywhere at the
      * expense of very slow execution time, or if {@code double} should be used
      * convenient places to gain speed. Almost never choose {@code true} in real
      * applications unless you are very sure; {@code true} is almost solely for
      * verification purposes.
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
      * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
      */
@@ -181,13 +181,13 @@ public class KolmogorovSmirnovDistributi
 
     /**
      * Calculates the exact value of {@code P(D_n < d)} using method described
      * in [1] and {@link org.apache.commons.math.fraction.BigFraction} (see
      * above).
      *
      * @param d statistic
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
      * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
      */
@@ -219,7 +219,7 @@ public class KolmogorovSmirnovDistributi
      * @param d statistic
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
      * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
      */
@@ -259,7 +259,7 @@ public class KolmogorovSmirnovDistributi
      * @return H matrix
      * @throws NumberIsTooLargeException if fractional part is greater than 1
      * @throws FractionConversionException if algorithm fails to convert
      * {@code h} to a {@link org.apache.commons.math.fraction.BigFraction} in
      * expressing {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
      */
@@ -96,12 +96,12 @@ public class KolmogorovSmirnovDistributi
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
-     * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
+     * to a {@link org.apache.commons.math3.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
@@ -121,7 +121,7 @@ public class KolmogorovSmirnovDistributi
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
-     * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
+     * to a {@link org.apache.commons.math3.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
@@ -135,14 +135,14 @@ public class KolmogorovSmirnovDistributi
      * @param d statistic
      * @param exact whether the probability should be calculated exact using
-     * {@link org.apache.commons.math.fraction.BigFraction} everywhere at the
+     * {@link org.apache.commons.math3.fraction.BigFraction} everywhere at the
      * expense of very slow execution time, or if {@code double} should be used
      * convenient places to gain speed. Almost never choose {@code true} in real
@@ -135,14 +135,14 @@ public class KolmogorovSmirnovDistributi
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
-     * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
+     * to a {@link org.apache.commons.math3.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
@@ -181,13 +181,13 @@ public class KolmogorovSmirnovDistributi
     /**
      * Calculates the exact value of {@code P(D_n < d)} using method described
-     * in [1] and {@link org.apache.commons.math.fraction.BigFraction} (see
+     * in [1] and {@link org.apache.commons.math3.fraction.BigFraction} (see
      * above).
      *
@@ -181,13 +181,13 @@ public class KolmogorovSmirnovDistributi
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
-     * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
+     * to a {@link org.apache.commons.math3.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
@@ -219,7 +219,7 @@ public class KolmogorovSmirnovDistributi
      * @return the two-sided probability of {@code P(D_n < d)}
      * @throws MathArithmeticException if algorithm fails to convert {@code h}
-     * to a {@link org.apache.commons.math.fraction.BigFraction} in expressing
+     * to a {@link org.apache.commons.math3.fraction.BigFraction} in expressing
      * {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.
@@ -259,7 +259,7 @@ public class KolmogorovSmirnovDistributi
      * @throws NumberIsTooLargeException if fractional part is greater than 1
      * @throws FractionConversionException if algorithm fails to convert
-     * {@code h} to a {@link org.apache.commons.math.fraction.BigFraction} in
+     * {@code h} to a {@link org.apache.commons.math3.fraction.BigFraction} in
      * expressing {@code d} as {@code (k - h) / m} for integer {@code k, m} and
      * {@code 0 <= h < 1}.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/LogNormalDistribution.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/distribution/LogNormalDistribution.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================